@@ -8,8 +8,8 @@ Created on Tue Jun 23 15:32:24 2020
 import numpy as np
 import scipy.interpolate as scintp
 from .utils import *
-import pyspeechhiker.utils as utils
-import pyspeechhiker.plottools as plottools
+import spychhiker.utils as utils
+import spychhiker.plottools as plottools
 import copy
 from .stats import RandomVar, ProsodyParam
 from .prosody import Contour
